@@ -7,7 +7,7 @@ aclocal -I m4
 echo "libtoolize"
 libtoolize --copy --force
 echo "gtkdocize --flavour=no-tmpl"
-gtkdocize --docdir Documentation/reference || exit 1
+gtkdocize --docdir Documentation/reference --flavour no-tmpl || exit 1
 echo "autoheader"
 autoheader
 echo "automake"
