@@ -216,7 +216,6 @@ static gboolean read_box(struct cube_reader *rd, GError **error)
 {
   int i;
   double cart[3][3];
-  float boxMat[3][3], fileMat[3][3], fileMatInv[3][3];
   gchar dir[3] = "XYZ";
 
   /* Read the box definition. */
@@ -260,39 +259,12 @@ static gboolean read_box(struct cube_reader *rd, GError **error)
 			   _("Wrong Cube format, primitive vectors are not 3D.\n"));
       return FALSE;
     }
-  /* We create the rotation matrix that pass from the cartesian
-     coordinates of the file to the cartesian coordinates of the box. */
-  boxMat[0][0] = rd->box[0];
-  boxMat[0][1] = rd->box[1];
-  boxMat[0][2] = rd->box[3];
-  boxMat[1][0] = 0.f;
-  boxMat[1][1] = rd->box[2];
-  boxMat[1][2] = rd->box[4];
-  boxMat[2][0] = 0.f;
-  boxMat[2][1] = 0.f;
-  boxMat[2][2] = rd->box[5];
-  fileMat[0][0] = (float)cart[0][0];
-  fileMat[0][1] = (float)cart[1][0];
-  fileMat[0][2] = (float)cart[2][0];
-  fileMat[1][0] = (float)cart[0][1];
-  fileMat[1][1] = (float)cart[1][1];
-  fileMat[1][2] = (float)cart[2][1];
-  fileMat[2][0] = (float)cart[0][2];
-  fileMat[2][1] = (float)cart[1][2];
-  fileMat[2][2] = (float)cart[2][2];
-  if (!matrix_invert(fileMatInv, fileMat))
+  if (!matrix_fromFullToBoxCartesian(rd->rot, cart, rd->box))
     {
       *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
 			   _("Wrong Cube format, cannot invert primitive vectors.\n"));
       return FALSE;
     }
-  matrix_productMatrix(rd->rot, boxMat, fileMatInv);
-  DBG_fprintf(stderr, "Cube: rotation matrix %8g %8g %8g\n"
-	      "                      %8g %8g %8g\n"
-	      "                      %8g %8g %8g\n",
-	      rd->rot[0][0], rd->rot[0][1], rd->rot[0][2],
-	      rd->rot[1][0], rd->rot[1][1], rd->rot[1][2],
-	      rd->rot[2][0], rd->rot[2][1], rd->rot[2][2]);
   return TRUE;
 }
 
