@@ -156,6 +156,7 @@ struct xsf_reader
   GHashTable *elements;
   VisuElement **nodeTypes;
   int nNodes;
+  float rot[3][3];
   float *coords;
   float *forces;
   GIOStatus status;
@@ -275,13 +276,19 @@ static gboolean read_box(struct xsf_reader *rd, double box[6], GError **error)
 			   _("Wrong XSF format, primitive vectors are not 3D.\n"));
       return FALSE;
     }
+  if (!matrix_fromFullToBoxCartesian(rd->rot, cart, box))
+    {
+      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+			   _("Wrong XSF format, cannot invert primitive vectors.\n"));
+      return FALSE;
+    }
   return TRUE;
 }
 
 static gboolean read_coords(struct xsf_reader *rd, GError **error)
 {
   int i, res, zele, nb;
-  float rcov, fx, fy, fz;
+  float rcov, f[3], coord[3];
   gchar *name, *ptChar;
   VisuElement *type;
   struct dataAscii *infos;
@@ -313,22 +320,21 @@ static gboolean read_coords(struct xsf_reader *rd, GError **error)
       *ptChar = '\0';
       /* The first three values are coordinates.
 	 Possible three others are forces. */
-      nb = sscanf(ptChar + 1, "%f %f %f %f %f %f\n", rd->coords + 3 * i,
-		  rd->coords + 3 * i + 1, rd->coords + 3 * i + 2, &fx, &fy, &fz);
+      nb = sscanf(ptChar + 1, "%f %f %f %f %f %f\n", coord + 0,
+		  coord + 1, coord + 2, f + 0, f + 1, f + 2);
       if (nb != 3 && nb != 6)
 	{
 	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
 			       _("Wrong XSF format, can't read coordinates.\n"));
 	  return FALSE;
 	}
+      matrix_productVector(rd->coords + 3 * i, rd->rot, coord);
       if (nb == 6)
 	{
 	  /* If forces where not used, we allocate then now. */
 	  if (!rd->forces)
 	    rd->forces = g_malloc(sizeof(float) * 3 * rd->nNodes);
-	  *(rd->forces + 3 * i    ) = fx;
-	  *(rd->forces + 3 * i + 1) = fy;
-	  *(rd->forces + 3 * i + 2) = fz;
+	  matrix_productVector(rd->forces + 3 * i, rd->rot, f);
 	}
       /* Try to find a z number instead of a name. */
       rcov = -1.f;
