@@ -70,6 +70,8 @@ void matrix_productMatrix(float matRes[3][3], float matA[3][3], float matB[3][3]
  */
 void matrix_productVector(float vectRes[3], float mat[3][3], float vect[3]);
 gboolean matrix_invert(float inv[3][3], float mat[3][3]);
+gboolean matrix_fromFullToBoxCartesian(float rot[3][3],
+				       double full[3][3], double box[6]);
 
 /**
  * matrix_reducePrimitiveVectors:
