@@ -133,11 +133,6 @@ static void onDataReadySignal(GObject *obj _U_, VisuData *dataObj, gpointer data
   DBG_fprintf(stderr, "Ext Legend: catch 'dataReadyForRendering' signal.\n");
   if (dataObj)
     {
-      if (visuDataGet_changeElementFlag(dataObj))
-	{
-	  DBG_fprintf(stderr,"Ext Legend: elements not changed, keep it.\n");
-	  return;
-	}
       extLegendIsBuilt = FALSE;
       extLegendDraw(dataObj);
     }
