@@ -357,7 +357,7 @@ int dataFileSet_file(VisuData *attachedVisuData, char* filename,
 #endif
   visuDataIter_new(attachedVisuData, &iter);
   for (visuDataIter_start(attachedVisuData, &iter); iter.node;
-       visuDataIter_next(attachedVisuData, &iter))
+       visuDataIter_nextNodeNumber(attachedVisuData, &iter))
     {
       /* If the file is not finished, we read until a non-void line
 	 and return this line. */
