@@ -55,6 +55,34 @@
 #include "surfaces.h"
 #include "pot2surf.h"
 
+/**
+ * SECTION:pot2surf
+ * @short_description: Creates surfaces from scalar fields.
+ *
+ * <para>Originally written by Luc Billard for his program
+ * VISUALISE. It has been since transformed to a single function and
+ * integrated in V_Sim. .pot file are text files which specification
+ * are the following :
+ * <itemizedlist>
+ * <listitem><para>1st line: full pathname of the potential file to
+ * read</para></listitem>
+ * <listitem><para>2nd line: full pathname of the surface file to
+ * build</para></listitem>
+ * <listitem><para>3rd line: an integer giving the nbr n of
+ * isosurfaces to build </para></listitem>
+ * <listitem><para>Each of the n following lines must match the
+ * pattern [value name] where value is a real number for the isovalue
+ * and name is the name given for the corresponding isosurface to
+ * build. Each surface should be named surface_*.</para></listitem>
+ * </itemizedlist>
+ * The function will fail if it finds no isosurface corresponding to
+ * some of the given isovalues. The <link
+ * linkend="v-sim-panelSurfacesTools">panelSurfacesTools</link>
+ * contains a frontend to build valid .instruc files. This panel is
+ * originally integrated in V_Sim. You can access it through the
+ * Convert tab in the Isosurfaces panel.</para>
+ */
+
 #define ISOSURFACES_FLAG_POTENTIAL "# potentialValue"
 
 
@@ -73,14 +101,16 @@ static int n1_tot, n2_tot;
 static int *itab = NULL;
 static double *xs = NULL, *ys = NULL, *zs = NULL, *xns = NULL, *yns = NULL, *zns = NULL;
 static gboolean pot2surfCreate_uniform_mesh(Surfaces **surf, ScalarField *field,
-			            double isoValue, int id, const gchar *name);
+					    double isoValue, int id,
+					    const gchar *name);
 static gboolean pot2surfCreate_nonuniform_mesh(Surfaces **surf, ScalarField *field,
-                                       double isoValue, int id, const gchar *name);
+					       double isoValue, int id,
+					       const gchar *name);
 static gboolean Create_surf(int id, int nelez3, int neleyz3, int nelexyz3,
                      int nPoints, int sizem1[3], int *iTab,
                      double *xsurf , double *ysurf , double *zsurf ,
                      double *xnsurf, double *ynsurf, double *znsurf,
-                     double isoValue, double ***scalarData, float scalarBox[6],
+                     double isoValue, double ***scalarData, double scalarBox[6],
                      const gchar *name, gboolean per, Surfaces **surf);
 
 /* Tables from :
@@ -1223,7 +1253,7 @@ static gboolean pot2surfCreate_uniform_mesh(Surfaces **surf, ScalarField *field,
   double dBox[6];   /*step of the mesh*/
   double *xsurf, *ysurf, *zsurf, *xnsurf, *ynsurf, *znsurf;
   double ***scalarData, val1, val2;
-  float scalarBox[6]; /*define the box edges and topology*/
+  double scalarBox[6]; /*define the box edges and topology*/
   gboolean per, status;
 
 /* Routine code*/
@@ -1506,7 +1536,7 @@ static gboolean pot2surfCreate_nonuniform_mesh(Surfaces **surf, ScalarField *fie
   double *xsurf, *ysurf, *zsurf, *xnsurf, *ynsurf, *znsurf;
   double *meshx, *meshy, *meshz;
   double ***scalarData, val1, val2;
-  float scalarBox[6]; /*define the box edges and topology*/
+  double scalarBox[6]; /*define the box edges and topology*/
   gboolean per, status;
 
 /* Routine code*/
@@ -1766,7 +1796,7 @@ static gboolean Create_surf(int id, int nelez3, int neleyz3, int nelexyz3,
                      int nPoints, int sizem1[3], int *iTab,
                      double *xsurf , double *ysurf , double *zsurf ,
                      double *xnsurf, double *ynsurf, double *znsurf,
-                     double isoValue, double ***scalarData, float scalarBox[6],
+                     double isoValue, double ***scalarData, double scalarBox[6],
                      const gchar *name, gboolean per, Surfaces **surf)
 {
 
@@ -1956,3 +1986,391 @@ static gboolean Create_surf(int id, int nelez3, int neleyz3, int nelexyz3,
   g_free(vTab);
   return TRUE;
 }
+
+
+/*****************************/
+/* XML files for iso-values. */
+/*****************************/
+
+/*
+   <surfaces>
+     <surface rendered="yes" iso-value="0.45" name="foo">
+       <hidden-by-planes status="yes" />
+       <color rgba="0.5 0.5 0.5 1." material="0.2 1. 0.5 0.5 0." />
+     </surface>
+   </surfaces>
+*/
+
+/* Known elements. */
+#define SURF_PARSER_ELEMENT_SURFACES  "surfaces"
+#define SURF_PARSER_ELEMENT_SURFACE   "surface"
+#define SURF_PARSER_ELEMENT_HIDE      "hidden-by-planes"
+#define SURF_PARSER_ELEMENT_COLOR     "color"
+/* Known attributes. */
+#define SURF_PARSER_ATTRIBUTES_RENDERED "rendered"
+#define SURF_PARSER_ATTRIBUTES_VALUE    "iso-value"
+#define SURF_PARSER_ATTRIBUTES_NAME     "name"
+#define SURF_PARSER_ATTRIBUTES_STATUS   "status"
+#define SURF_PARSER_ATTRIBUTES_RGBA     "rgba"
+#define SURF_PARSER_ATTRIBUTES_MATERIAL "material"
+
+struct _surfaces_xml
+{
+  gchar *name;
+  float iso;
+  gboolean rendered, masked;
+  gboolean colorSet, materialSet;
+  float color[4], material[5];
+};
+
+static gboolean startSurfaces;
+
+/* This method is called for every element that is parsed.
+   The user_data must be a GList of _surfaces_xml. When a 'surface'
+   element, a new struct instance is created and prepend in the list.
+   When 'hidden-by-planes' or other qualificative elements are
+   found, the first surface of the list is modified accordingly. */
+static void surfacesXML_element(GMarkupParseContext *context _U_,
+                          const gchar         *element_name,
+                          const gchar        **attribute_names,
+                          const gchar        **attribute_values,
+                          gpointer             user_data,
+                          GError             **error)
+{
+  GList **surfacesList;
+  struct _surfaces_xml *surf;
+  int i;
+
+  g_return_if_fail(user_data);
+  surfacesList = (GList **)user_data;
+
+  DBG_fprintf(stderr, "Surf parser: found '%s' element.\n", element_name);
+  if (!strcmp(element_name, SURF_PARSER_ELEMENT_SURFACES))
+    {
+      /* Should have no attributes. */
+      if (attribute_names[0])
+	{
+	  g_set_error(error, G_MARKUP_ERROR, G_MARKUP_ERROR_UNKNOWN_ATTRIBUTE,
+		      _("Unexpected attribute '%s' for element '%s'."),
+		      attribute_names[0], SURF_PARSER_ELEMENT_SURFACES);
+	  return;
+	}
+      /* Initialise the surfacesList. */
+      if (*surfacesList)
+	{
+	  g_set_error(error, G_MARKUP_ERROR, G_MARKUP_ERROR_PARSE,
+		      _("DTD error: element '%s' should appear only once."),
+		      SURF_PARSER_ELEMENT_SURFACES);
+	  return;
+	}
+      *surfacesList = (GList*)0;
+      startSurfaces = TRUE;
+    }
+  else if (!strcmp(element_name, SURF_PARSER_ELEMENT_SURFACE))
+    {
+      surf = g_malloc(sizeof(struct _surfaces_xml));
+      surf->name        = (gchar*)0;
+      surf->rendered    = TRUE;
+      surf->masked      = TRUE;
+      surf->iso         = 12345.6789f;
+      surf->colorSet    = FALSE;
+      surf->materialSet = FALSE;
+
+      /* We parse the attributes. */
+      for (i = 0; attribute_names[i]; i++)
+	{
+	  if (!strcmp(attribute_names[i], SURF_PARSER_ATTRIBUTES_NAME))
+	    surf->name = g_strdup(attribute_values[i]);
+	  else if (!strcmp(attribute_names[i], SURF_PARSER_ATTRIBUTES_RENDERED))
+	    {
+	      if (!strcmp(attribute_values[i], "yes"))
+		surf->rendered = TRUE;
+	      else if (!strcmp(attribute_values[i], "no"))
+		surf->rendered = FALSE;
+	      else
+		g_set_error(error, G_MARKUP_ERROR, G_MARKUP_ERROR_INVALID_CONTENT,
+			    _("Invalid value '%s' for attribute '%s'."),
+			    attribute_values[i], SURF_PARSER_ATTRIBUTES_RENDERED);
+	    }
+	  else if (!strcmp(attribute_names[i], SURF_PARSER_ATTRIBUTES_VALUE))
+	    {
+	      if (!sscanf(attribute_values[i], "%f", &surf->iso) == 1)
+		g_set_error(error, G_MARKUP_ERROR, G_MARKUP_ERROR_INVALID_CONTENT,
+			    _("Invalid value '%s' for attribute '%s'."),
+			    attribute_values[i], SURF_PARSER_ATTRIBUTES_VALUE);
+	    }
+	  else
+	    g_set_error(error, G_MARKUP_ERROR, G_MARKUP_ERROR_UNKNOWN_ATTRIBUTE,
+			_("Unexpected attribute '%s' for element '%s'."),
+			attribute_names[i], SURF_PARSER_ELEMENT_SURFACE);
+	  if (*error)
+	    {
+	      g_free(surf->name);
+	      g_free(surf);
+	      return;
+	    }
+	}
+      /* We check the mandatory attribute. */
+      if (surf->iso == 12345.6789f)
+	{
+	  g_set_error(error, G_MARKUP_ERROR, G_MARKUP_ERROR_PARSE,
+		      _("Missing attribute '%s' for element '%s'."),
+		      SURF_PARSER_ATTRIBUTES_VALUE, SURF_PARSER_ELEMENT_SURFACE);
+	  g_free(surf->name);
+	  g_free(surf);
+	  return;
+	}
+      DBG_fprintf(stderr, "Surf parser: add a new surface '%s' %f %d.\n",
+		  (surf->name)?surf->name:"None", surf->iso, surf->rendered);
+      *surfacesList = g_list_prepend(*surfacesList, (gpointer)surf);
+    }
+  else if (startSurfaces && !strcmp(element_name, SURF_PARSER_ELEMENT_HIDE))
+    {
+      if (!*surfacesList)
+	{
+	  g_set_error(error, G_MARKUP_ERROR, G_MARKUP_ERROR_INVALID_CONTENT,
+		      _("DTD error: parent element '%s' of element '%s' is missing."),
+		      SURF_PARSER_ELEMENT_SURFACE, SURF_PARSER_ELEMENT_HIDE);
+	  return;
+	}
+      surf = (struct _surfaces_xml*)((*surfacesList)->data);
+
+      /* We read the mandatory attribute. */
+      if (attribute_names[0])
+	{
+	  if (!strcmp(attribute_names[0], SURF_PARSER_ATTRIBUTES_STATUS))
+	    {
+	      if (!strcmp(attribute_values[0], "yes"))
+		surf->masked = TRUE;
+	      else if (!strcmp(attribute_values[0], "no"))
+		surf->masked = FALSE;
+	      else
+		g_set_error(error, G_MARKUP_ERROR, G_MARKUP_ERROR_INVALID_CONTENT,
+			    _("Invalid value '%s' for attribute '%s'."),
+			    attribute_values[0], SURF_PARSER_ATTRIBUTES_STATUS);
+	    }
+	  else
+	    g_set_error(error, G_MARKUP_ERROR, G_MARKUP_ERROR_UNKNOWN_ATTRIBUTE,
+			_("Unexpected attribute '%s' for element '%s'."),
+			attribute_names[0], SURF_PARSER_ELEMENT_HIDE);
+	}
+      else
+	g_set_error(error, G_MARKUP_ERROR, G_MARKUP_ERROR_PARSE,
+		    _("Missing attribute '%s' for element '%s'."),
+		    SURF_PARSER_ATTRIBUTES_VALUE, SURF_PARSER_ELEMENT_SURFACE);
+      if (*error)
+	return;
+
+    }
+  else if (startSurfaces && !strcmp(element_name, SURF_PARSER_ELEMENT_COLOR))
+    {
+      if (!*surfacesList)
+	{
+	  g_set_error(error, G_MARKUP_ERROR, G_MARKUP_ERROR_INVALID_CONTENT,
+		      _("DTD error: parent element '%s' of element '%s' is missing."),
+		      SURF_PARSER_ELEMENT_SURFACE, SURF_PARSER_ELEMENT_COLOR);
+	  return;
+	}
+      surf = (struct _surfaces_xml*)((*surfacesList)->data);
+
+      for(i = 0; attribute_names[i]; i++)
+	{
+	  if (!strcmp(attribute_names[i], SURF_PARSER_ATTRIBUTES_RGBA))
+	    {
+	      if (sscanf(attribute_values[i], "%g %g %g %g",
+			 surf->color, surf->color + 1,
+			 surf->color + 2, surf->color + 3) != 4)
+		g_set_error(error, G_MARKUP_ERROR, G_MARKUP_ERROR_INVALID_CONTENT,
+			    _("Invalid value '%s' for attribute '%s'."),
+			    attribute_values[i], SURF_PARSER_ATTRIBUTES_RGBA);
+	      else
+		surf->colorSet = TRUE;
+	    }
+	  else if (!strcmp(attribute_names[i], SURF_PARSER_ATTRIBUTES_MATERIAL))
+	    {
+	      if (sscanf(attribute_values[i], "%g %g %g %g %g",
+			 surf->material, surf->material + 1, surf->material + 2,
+			 surf->material + 3, surf->material + 4) != 5)
+		g_set_error(error, G_MARKUP_ERROR, G_MARKUP_ERROR_INVALID_CONTENT,
+			    _("Invalid value '%s' for attribute '%s'."),
+			    attribute_values[i], SURF_PARSER_ATTRIBUTES_MATERIAL);
+	      else
+		surf->materialSet = TRUE;
+	    }
+	  else
+	    g_set_error(error, G_MARKUP_ERROR, G_MARKUP_ERROR_UNKNOWN_ATTRIBUTE,
+			_("Unexpected attribute '%s' for element '%s'."),
+			attribute_names[i], SURF_PARSER_ELEMENT_COLOR);
+	  if (*error)
+	    return;
+	}
+    }
+  else if (startSurfaces)
+    {
+      /* We silently ignore the element if surfacesList is unset, but
+	 raise an error if surfacesList has been set. */
+      g_set_error(error, G_MARKUP_ERROR, G_MARKUP_ERROR_UNKNOWN_ELEMENT,
+		  _("Unexpected element '%s'."), element_name);
+    }
+}
+
+/* Check when a element is closed that everything required has been set. */
+void surfacesXML_end(GMarkupParseContext *context _U_,
+		      const gchar         *element_name,
+		      gpointer             user_data _U_,
+		      GError             **error _U_)
+{
+  if (!strcmp(element_name, SURF_PARSER_ELEMENT_SURFACES))
+    startSurfaces = FALSE;
+}
+
+/* What to do when an error is raised. */
+static void surfacesXML_error(GMarkupParseContext *context _U_,
+			GError              *error,
+			gpointer             user_data)
+{
+  GList *tmpLst;
+
+  DBG_fprintf(stderr, "Surf parser: error raised '%s'.\n", error->message);
+  g_return_if_fail(user_data);
+
+  /* We free the current list of surfaces. */
+  tmpLst = *(GList**)user_data;
+  while (tmpLst)
+    {
+      g_free(((struct _surfaces_xml*)tmpLst->data)->name);
+      g_free(tmpLst->data);
+      tmpLst = g_list_next(tmpLst);
+    }
+  g_list_free(*(GList**)user_data);
+}
+
+gboolean pot2surfParse_XMLFile(const gchar* filename, Surfaces **surfaces,
+			       ScalarField *field, GError **error)
+{
+  GMarkupParseContext* xmlContext;
+  GMarkupParser parser;
+  gboolean status;
+  gsize size;
+  gchar *buffer;
+  GList *list, *tmpLst;
+  int position, nb;
+  struct _surfaces_xml *surf;
+  SurfaceResource *res;
+  Color *color;
+
+  g_return_val_if_fail(filename && surfaces && field, FALSE);
+
+  buffer = (gchar*)0;
+  if (!g_file_get_contents(filename, &buffer, &size, error))
+    return FALSE;
+
+  /* Create context. */
+  list = (GList*)0;
+  parser.start_element = surfacesXML_element;
+  parser.end_element   = surfacesXML_end;
+  parser.text          = NULL;
+  parser.passthrough   = NULL;
+  parser.error         = surfacesXML_error;
+  xmlContext = g_markup_parse_context_new(&parser, 0, &list, NULL);
+
+  /* Parse data. */
+  startSurfaces = FALSE;
+  status = g_markup_parse_context_parse(xmlContext, buffer, size, error);
+
+  /* Free buffers. */
+  g_markup_parse_context_free(xmlContext);
+  g_free(buffer);
+
+  if (!status)
+    return FALSE;
+
+  if (!list)
+    {
+      *error = g_error_new(G_MARKUP_ERROR, G_MARKUP_ERROR_EMPTY,
+			  _("No iso-value found."));
+      return FALSE;
+    }
+
+  /* Need to reverse the list since elements have been prepended. */
+  list = g_list_reverse(list);
+
+  /* Convert the list to new isosurfaces. */
+  DBG_fprintf(stderr, "Surf parser: create %d new surfaces for %p.\n",
+	      g_list_length(list), (gpointer)(*surfaces));
+  tmpLst = list;
+  while(tmpLst)
+    {
+      surf = (struct _surfaces_xml*)tmpLst->data;
+      nb = isosurfacesGet_newId(*surfaces);
+      if (pot2surfCreate(surfaces, field, surf->iso, nb, surf->name))
+	{
+	  res = isosurfacesGet_surfaceResource(*surfaces, nb);
+	  res->rendered = surf->rendered;
+	  res->sensitiveToMaskingPlanes = surf->masked;
+	  if (surf->colorSet)
+	    {
+	      color = colorAdd_floatRGBA(surf->color, &position);
+	      res->color->rgba[0] = color->rgba[0];
+	      res->color->rgba[1] = color->rgba[1];
+	      res->color->rgba[2] = color->rgba[2];
+	      res->color->rgba[3] = color->rgba[3];
+	    }
+	  if (surf->materialSet)
+	    {
+	      res->material[0] = surf->material[0];
+	      res->material[1] = surf->material[1];
+	      res->material[2] = surf->material[2];
+	      res->material[3] = surf->material[3];
+	      res->material[4] = surf->material[4];
+	    }
+	}
+      g_free(surf->name);
+      g_free(surf);
+      tmpLst = g_list_next(tmpLst);
+    }
+  g_list_free(list);
+
+  return TRUE;
+}
+
+gboolean pot2surfSave_XMLFile(const gchar* filename, float *values,
+			      SurfaceResource **res, int n, GError **error)
+{
+  gboolean valid;
+  GString *output;
+  int i;
+
+  /* We actually output the values. */
+  output = g_string_new("  <surfaces>\n");
+  for (i = 0; i < n; i++)
+    {
+      g_string_append_printf(output, "    <surface rendered=\"%s\" iso-value=\"%g\"",
+			     (res[i]->rendered)?"yes":"no", values[i]);
+      if (res[i]->surfnom)
+	g_string_append_printf(output, " name=\"%s\"", res[i]->surfnom);
+      g_string_append(output, ">\n");
+      g_string_append_printf(output, "      <hidden-by-planes status=\"%s\" />\n",
+			     (res[i]->sensitiveToMaskingPlanes)?"yes":"no");
+      g_string_append_printf(output, "      <color rgba=\"%g %g %g %g\""
+			     " material=\"%g %g %g %g %g\" />\n",
+			     res[i]->color->rgba[0], res[i]->color->rgba[1],
+			     res[i]->color->rgba[2], res[i]->color->rgba[3],
+			     res[i]->material[0], res[i]->material[1],
+			     res[i]->material[2], res[i]->material[3],
+			     res[i]->material[4]);
+      g_string_append(output, "    </surface>\n");
+    }
+  g_string_append(output, "  </surfaces>");
+
+  valid = visuToolsSubstitute_XML(output, filename, "surfaces", error);
+  if (!valid)
+    {
+      g_string_free(output, TRUE);
+      return FALSE;
+    }
+  
+  valid = g_file_set_contents(filename, output->str, -1, error);
+  g_string_free(output, TRUE);
+  return valid;
+}
