@@ -204,7 +204,9 @@ GtkWidget* dumpDialog_new(VisuData *dataObj, GtkWindow *parent,
 
   DBG_fprintf(stderr, "Gtk DumpDialog : creating a new DumpDialog object.\n");
 
-  dumpDialog = DUMP_DIALOG(g_object_new(dumpDialog_get_type(), NULL));
+  dumpDialog = DUMP_DIALOG(g_object_new(DUMP_DIALOG_TYPE, NULL));
+  gtk_window_set_title(GTK_WINDOW(dumpDialog),
+		       _("Export to a file (image, atomic structures...)"));
   klass = DUMP_DIALOG_CLASS(G_OBJECT_GET_CLASS(dumpDialog));
   gtk_dialog_set_has_separator(GTK_DIALOG(dumpDialog), FALSE);
   /* This is to avoid a bug in gtk 2.4 */
@@ -458,7 +460,8 @@ static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data)
 
   dumpDialog = DUMP_DIALOG(data);
 
-  DBG_fprintf(stderr, "Gtk DumpDialog : catch the 'response' signal.\n");
+  DBG_fprintf(stderr, "Gtk DumpDialog: catch the 'response' signal:"
+	      " %d (ACCEPT is %d).\n", id, GTK_RESPONSE_ACCEPT);
   /* Get the filename. */
   filename = (gchar*)0;
   formatInt = -1;
