@@ -185,6 +185,7 @@ void gtkAboutBuild_window(GtkMain *main)
 
       wd = lookup_widget(main->aboutDialog, "textviewChangelog");
       gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(wd), GTK_WRAP_WORD);
+      gtk_text_view_set_justification (GTK_TEXT_VIEW(wd), GTK_JUSTIFY_FILL);
       text = gtk_text_view_get_buffer(GTK_TEXT_VIEW(wd));
       
       /* Parse here the XML to get only the relevant entries. */
@@ -435,7 +436,7 @@ static void aboutXML_element(GMarkupParseContext *context _U_,
 							   attribute_values[i],
 							   -1, "bold", NULL);
 		  gtk_text_buffer_get_end_iter(text, &iter);
-		  gtk_text_buffer_insert(text, &iter, ":\n\n", -1);
+		  gtk_text_buffer_insert(text, &iter, _(":\n\n"), -1);
 		}
 	    }
 	}
@@ -444,7 +445,10 @@ static void aboutXML_element(GMarkupParseContext *context _U_,
     {
       if (startAbout)
 	{
-	  /* Should have 1 mandatory attribute. */
+	  gtk_text_buffer_get_end_iter(text, &iter);
+	  gtk_text_buffer_insert(text, &iter, "\342\200\242\t", -1);
+
+	  /* May have the type attribute. */
 	  for (i = 0; attribute_names[i]; i++)
 	    {
 	      if (!strcmp(attribute_names[i], PICK_PARSER_ATTRIBUTES_TYPE))
@@ -454,10 +458,10 @@ static void aboutXML_element(GMarkupParseContext *context _U_,
 							   attribute_values[i],
 							   -1, "italic", NULL);
 		  gtk_text_buffer_get_end_iter(text, &iter);
-		  gtk_text_buffer_insert(text, &iter, ": ", -1);
-		  startLi = TRUE;
+		  gtk_text_buffer_insert(text, &iter, _(": "), -1);
 		}
 	    }
+	  startLi = TRUE;
 	}
     }
 }
@@ -476,12 +480,12 @@ static void aboutXML_end(GMarkupParseContext *context _U_,
 
   if (!strcmp(element_name, PICK_PARSER_ELEMENT_MILESTONE))
     startAbout = FALSE;
-  else if (!strcmp(element_name, PICK_PARSER_ELEMENT_ENTRY))
+  else if (!strcmp(element_name, PICK_PARSER_ELEMENT_ENTRY) && startAbout)
     {
       gtk_text_buffer_get_end_iter(text, &iter);
       gtk_text_buffer_insert(text, &iter, "\n", -1);
     }
-  else if (!strcmp(element_name, PICK_PARSER_ELEMENT_LI))
+  else if (!strcmp(element_name, PICK_PARSER_ELEMENT_LI) && startAbout)
     {
       startLi = FALSE;
       gtk_text_buffer_get_end_iter(text, &iter);
@@ -505,8 +509,8 @@ static void aboutXML_text(GMarkupParseContext *context _U_,
     {
       gtk_text_buffer_get_end_iter(text, &iter);
       gtk_text_buffer_insert(text, &iter, buf, text_len);
-      gtk_text_buffer_get_end_iter(text, &iter);
-      gtk_text_buffer_insert(text, &iter, "\n", -1);
+/*       gtk_text_buffer_get_end_iter(text, &iter); */
+/*       gtk_text_buffer_insert(text, &iter, "\n", -1); */
     }
 }
 
