@@ -820,7 +820,7 @@ static void onDuplicate(GtkButton *button _U_, gpointer data _U_)
   GtkTreeIter iter;
   gboolean valid, custom;
   VisuElement *element;
-  float coord[3];
+  float coord[3], *trans;
   VisuNode *node;
 
   DBG_fprintf(stderr, "Gtk Move: duplicate selected nodes.\n");
@@ -846,17 +846,22 @@ static void onDuplicate(GtkButton *button _U_, gpointer data _U_)
   if (!lst)
     return;
 
+  trans = visuDataGet_XYZtranslation(dataObj);
   for (tmpLst = lst; tmpLst; tmpLst = g_list_next(tmpLst))
     {
       node = visuDataGet_nodeFromNumber
 	(dataObj, (guint)GPOINTER_TO_INT(tmpLst->data));
       visuDataGet_nodePosition(dataObj, node, coord);
+      coord[0] -= trans[0];
+      coord[1] -= trans[1];
+      coord[2] -= trans[2];
       if (custom)
 	visuDataAdd_nodeFromElement(dataObj, element, coord, !tmpLst->next);
       else
 	visuDataAdd_nodeFromIndex(dataObj, node->posElement, coord, !tmpLst->next);
     }
   g_list_free(lst);
+  g_free(trans);
 
   /* We update all drawings. */
   if (custom)
