@@ -1134,6 +1134,7 @@ static gboolean onKeyPressed(GtkWidget *widget _U_, GdkEventKey *event,
 {
   SimplifiedEvents ev;
   RenderingWindow *window;
+  GList *cameras, *head;
 
   window = RENDERING_WINDOW(data);
   g_return_val_if_fail(window, TRUE);
@@ -1146,11 +1147,16 @@ static gboolean onKeyPressed(GtkWidget *widget _U_, GdkEventKey *event,
   if(event->keyval == GDK_r || event->keyval == GDK_R)
     {
       ev.letter = 'r';
-      renderingWindowPush_message(window, _("Restore saved camera position."));
+      /* If any camera, print a message. */
+      visuInteractiveGet_savedCameras(window->inter, &cameras, &head);
+      if (cameras)
+	renderingWindowPush_message(window, _("Restore saved camera position."));
+      else
+	renderingWindowPush_message(window, _("No saved camera. Use 's' to save one."));
 #if GLIB_MINOR_VERSION > 13
-      g_timeout_add_seconds(3, timeOutPopMessage, (gpointer)window);
+	  g_timeout_add_seconds(3, timeOutPopMessage, (gpointer)window);
 #else
-      g_timeout_add(3000, timeOutPopMessage, (gpointer)window);
+	  g_timeout_add(3000, timeOutPopMessage, (gpointer)window);
 #endif
     }
   else if(event->keyval == GDK_s || event->keyval == GDK_S)
@@ -1922,8 +1928,7 @@ static void onDumpButtonClicked(GtkButton *button _U_, gpointer user_data)
 				updateDumpProgressBar, (gpointer)dumpBar);
 
       if (!res && error)
-	visuGtkRaise_warning(_("Saving a file"), error->message,
-			     GTK_WINDOW(user_data));
+	visuGtkRaise_warning(_("Saving a file"), error->message, (GtkWindow*)0);
       gdk_window_set_cursor(GDK_WINDOW((GTK_WIDGET(dump))->window), NULL);
       if (error)
 	g_error_free(error);
