@@ -2252,7 +2252,8 @@ static gint onSortNames(GtkTreeModel *model, GtkTreeIter *a,
 {
   gint kindA, kindB;
   gchar *lblA, *lblB;
-  gint diff;
+  gint diff, iSetA, iSetB;
+  GtkTreeIter parentA, parentB;
 
   /* We always sort the kind first. */
   gtk_tree_model_get(model, a, COLUMN_FILE_KIND, &kindA, -1);
@@ -2262,13 +2263,24 @@ static gint onSortNames(GtkTreeModel *model, GtkTreeIter *a,
     return (kindB - kindA);
   else
     {
-      gtk_tree_model_get(model, a, COLUMN_NAME_UTF8, &lblA, -1);
-      gtk_tree_model_get(model, b, COLUMN_NAME_UTF8, &lblB, -1);
+      if (gtk_tree_model_iter_parent(model, &parentA, a) &&
+	  gtk_tree_model_iter_parent(model, &parentB, b))
+	{
+	  gtk_tree_model_get(model, a, COLUMN_DATE, &iSetA, -1);
+	  gtk_tree_model_get(model, b, COLUMN_DATE, &iSetB, -1);
 
-      diff = g_utf8_collate(lblA, lblB);
+	  diff = iSetA - iSetB;
+	}
+      else
+	{
+	  gtk_tree_model_get(model, a, COLUMN_NAME_UTF8, &lblA, -1);
+	  gtk_tree_model_get(model, b, COLUMN_NAME_UTF8, &lblB, -1);
 
-      g_free(lblA);
-      g_free(lblB);
+	  diff = g_utf8_collate(lblA, lblB);
+
+	  g_free(lblA);
+	  g_free(lblB);
+	}
 
       return diff;
     }
