@@ -160,6 +160,7 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
   unsigned int *nattyp, natom;
   gchar *pt;
   OpenGLBoxBoundaries bc;
+  gboolean reduced;
 
   int nbcolumn;
 
@@ -174,6 +175,7 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
 
   line = g_string_new("");
   unit = unit_undefined;
+  reduced = FALSE;
 
   /* Storage of number of elements per types. */
   nbcolumn = 0;
@@ -245,6 +247,8 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
 		unit = unit_bohr;
 	      else if (!strcmp(tmpStr, "angstroem") || !strcmp(tmpStr, "angstroemd0"))
 		unit = unit_angstroem;
+	      else if (!strcmp(tmpStr, "reduced") || !strcmp(tmpStr, "reducedd0"))
+		reduced = TRUE;
 	      else
 		g_warning("Unknown unit '%s'.", tmpStr);
 	    }
@@ -525,19 +529,6 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
   for (i = 0; i < ntype; i++) natom += nattyp[i];
   g_free(nattyp);
   g_free(types);
-         
-  /* Store the coordinates */
-  for(iNodes = 0; iNodes < nNodesSet; iNodes++)
-    visuDataAdd_nodeFromElement(data, nodeTypes[iNodes],
-				coords + 3 * iNodes, FALSE);
-
-#ifdef TESTNEW
-  if ( test_Routine(coords, dcoord, nodeTypes) == FALSE )
-    return -1;
-#endif
-
-  g_free(nodeTypes);
-  g_free(coords);
 
   /* Set the commentary. */
   bc = BOX_FREE;
@@ -562,6 +553,27 @@ static int read_Xyz_File(VisuData *data, GIOChannel *flux, int nSet, GError **er
       tmpLst = g_list_next(tmpLst);
     }
   g_list_free(lst);
+         
+  /* Store the coordinates */
+  for(iNodes = 0; iNodes < nNodesSet; iNodes++)
+    {
+      if (reduced)
+	{
+	  coords[3 * iNodes + 0] *= box[0];
+	  coords[3 * iNodes + 1] *= box[1];
+	  coords[3 * iNodes + 2] *= box[2];
+	}
+      visuDataAdd_nodeFromElement(data, nodeTypes[iNodes],
+				  coords + 3 * iNodes, FALSE);
+    }
+
+#ifdef TESTNEW
+  if ( test_Routine(coords, dcoord, nodeTypes) == FALSE )
+    return -1;
+#endif
+
+  g_free(nodeTypes);
+  g_free(coords);
 
   if (bc != BOX_FREE)
     {
