@@ -1022,7 +1022,7 @@ void commandLineFree_all()
     g_free(argBgImageFile);
 
   if (argOptionTable)
-    g_free(argOptionTable);
+    g_hash_table_destroy(argOptionTable);
 
   if (argPlanesFileName)
     g_free(argPlanesFileName);
